#pragma once

#include "volumeshop.h"

#include "RendererPlugin.h"
#include "PluginInstance.h"
#include "Renderer.h"
#include "Exception.h"
#include "Shader.h"
#include "ResourceTexture2D.h"

class RendererTutorial : public Renderer, public PluginInstance<RendererPlugin>
{

public:

	RendererTutorial(Plugin & pluPlugin) : PluginInstance(pluPlugin)
	{
		m_pSphere = gluNewQuadric();

		if (!m_pSphere)
			throw Exception("Error generating quadric!");

		gluQuadricOrientation(m_pSphere,GLU_OUTSIDE);
		gluQuadricNormals(m_pSphere,GLU_SMOOTH);
	};
 
	virtual ~RendererTutorial()
	{
		if (m_pSphere)
		{
			gluDeleteQuadric(m_pSphere);
			m_pSphere = NULL;
		}	
	};

	virtual void idle()
	{
	};

	virtual void display(Canvas & canCanvas)
	{
		canCanvas.bind();

		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();
		gluPerspective(45.0f,1.0f,0.25f,4096.0f);

		glMatrixMode(GL_MODELVIEW);
		glLoadIdentity();
		gluLookAt(0.0f,0.0f,-1024.0f,0.0f,0.0f,0.0f,1.0f,0.0f,0.0f);

		glEnable(GL_DEPTH_TEST);
		glDepthFunc(GL_LESS);

		const float vfSpecularReflectance[] = { 0.6f, 0.6f, 0.6f, 1.0f };
		glMaterialfv(GL_FRONT_AND_BACK,GL_SPECULAR, vfSpecularReflectance);
		
		const float fShininess = 32.0f;
		glMaterialf(GL_FRONT_AND_BACK,GL_SHININESS,fShininess);
	
		const float vfLightPosition[] = { 0.0f, 0.0f, -1.0f, 0.0f };
		glLightfv(GL_LIGHT0, GL_POSITION, vfLightPosition);

		glEnable(GL_LIGHTING);
		glEnable(GL_LIGHT0);
		glEnable(GL_NORMALIZE);

		glEnable(GL_COLOR_MATERIAL);
		glColorMaterial(GL_FRONT_AND_BACK,GL_DIFFUSE);
		glColor4f(1.0f,0.0f,0.0f,1.0f);

		gluSphere(m_pSphere,128.0,256,256);

		canCanvas.release();
	};

	virtual void reshape(const unsigned int uWidth, const unsigned int uHeight)
	{
		GetPlugin().update();
	};

private:

	GLUquadric *m_pSphere;
};

DECLARE_RENDERERPLUGIN(RendererTutorial)