//<vertex>
	varying vec3 vecNormal;

	void main()
	{		
		vecNormal = normalize(gl_NormalMatrix * gl_Normal);
		gl_Position = ftransform();
		gl_TexCoord[0] = gl_MultiTexCoord0;
	}

//</vertex>


//<fragment>
	varying vec3 vecNormal;
	uniform sampler2D samTexture;

	void directionalLight(in vec3 vecN, in float fShininess, inout vec4 vecAmbient, inout vec4 vecDiffuse, inout vec4 vecSpecular)
	{
		vec3 vecL = normalize(gl_LightSource[0].position.xyz);
	   
		float fNdotL = dot(vecN, vecL);
	   
		if (fNdotL > 0.0)
		{   
			vec3 vecH = normalize(gl_LightSource[0].halfVector.xyz);
			float fNdotH = dot(vecN,vecH);

			vecDiffuse  += gl_LightSource[0].diffuse  * fNdotL;
			vecSpecular += gl_LightSource[0].specular * pow(max(fNdotH, 0.0), fShininess);
		}
	   
		vecAmbient  += gl_LightSource[0].ambient;
	}

	void main()
	{
		vec3 vecN = normalize(vecNormal);
		
		vec4 vecAmbient = vec4(0.0,0.0,0.0,0.0);
		vec4 vecDiffuse = vec4(0.0,0.0,0.0,0.0);
		vec4 vecSpecular = vec4(0.0,0.0,0.0,0.0);
	   
		directionalLight(vecN, gl_FrontMaterial.shininess, vecAmbient, vecDiffuse, vecSpecular);

		vec4 vecTexture = texture2D(samTexture,gl_TexCoord[0].xy);

		vec4 vecResult  = (vecAmbient * gl_FrontMaterial.ambient*vecTexture) +
			(vecDiffuse  * gl_FrontMaterial.diffuse*vecTexture) +
			(vecSpecular * gl_FrontMaterial.specular);

		vecResult = clamp(vecResult, 0.0, 1.0);
		gl_FragColor = vecResult;
	
	}

//</fragment>
