//<vertex>
	varying vec3 vecNormal;
	uniform sampler2D samDisplacement;
	uniform float fDisplacement;

	void main()
	{		
		vecNormal = normalize(gl_NormalMatrix * gl_Normal);
		
		vec4 vecDisplacement = texture2D(samDisplacement,gl_MultiTexCoord0.xy);		
		vec4 vecVertex = gl_Vertex + vec4(gl_Normal,0.0)*vecDisplacement.a*fDisplacement;
		
		gl_Position = gl_ModelViewProjectionMatrix * vecVertex;
		gl_TexCoord[0] = gl_MultiTexCoord0;
	}

//</vertex>


//<fragment>
	varying vec3 vecNormal;
	uniform sampler2D samTexture;
	uniform sampler2D samDisplacement;
	uniform float fDisplacement;

	void directionalLight(in vec3 vecN, in float fShininess, inout vec4 vecAmbient, inout vec4 vecDiffuse, inout vec4 vecSpecular)
	{
		vec3 vecL = normalize(gl_LightSource[0].position.xyz);
	   
		float fNdotL = dot(vecN, vecL);
	   
		if (fNdotL > 0.0)
		{   
			vec3 vecH = normalize(gl_LightSource[0].halfVector.xyz);
			float fNdotH = dot(vecN,vecH);

			vecDiffuse  += gl_LightSource[0].diffuse  * fNdotL;
			vecSpecular += gl_LightSource[0].specular * pow(max(fNdotH, 0.0), fShininess);
		}
	   
		vecAmbient  += gl_LightSource[0].ambient;
	}

	void main()
	{
		vec2 vecOffset;
		vecOffset.x = 0.5*(texture2DOffset(samDisplacement,gl_TexCoord[0].xy,ivec2(-1.0,0.0)).a -  texture2DOffset(samDisplacement,gl_TexCoord[0].xy,ivec2(1.0,0.0)).a); 
		vecOffset.y = 0.5*(texture2DOffset(samDisplacement,gl_TexCoord[0].xy,ivec2(0.0,1.0)).a -  texture2DOffset(samDisplacement,gl_TexCoord[0].xy,ivec2(0.0,-1.0)).a);
		vecOffset *= fDisplacement;
	
		vec3 vecN = vecNormal;
		vecN.xy += vecOffset;
		vecN = normalize(vecN);
		
		vec4 vecAmbient = vec4(0.0,0.0,0.0,0.0);
		vec4 vecDiffuse = vec4(0.0,0.0,0.0,0.0);
		vec4 vecSpecular = vec4(0.0,0.0,0.0,0.0);
	   
		directionalLight(vecN, gl_FrontMaterial.shininess, vecAmbient, vecDiffuse, vecSpecular);

		vec4 vecTexture = texture2D(samTexture,gl_TexCoord[0].xy);

		vec4 vecResult  = (vecAmbient * gl_FrontMaterial.ambient*vecTexture) +
			(vecDiffuse  * gl_FrontMaterial.diffuse*vecTexture) +
			(vecSpecular * gl_FrontMaterial.specular);

		vecResult = clamp(vecResult, 0.0, 1.0);
		gl_FragColor = vecResult;
	
	}

//</fragment>
